# coding: utf-8

"""
    Zadara Provisioning Portal API

     # Overview  This document outlines the methods available for creation and high-level administration of Zadara Storage VPSAs via a Zadara Storage Provisioning Portal. This API supports form-encoded requests, and can return either JSON or XML responses.  ## Endpoint  The base URL for the requests is the Provisioning Portal URL you created your VPSA through - for example: https://manage.zadarastorage.com/, and all APIs will be prefixed with /api as noted in the documentation below.  ## Authentication  To use this API, an authentication token is required. The API for retrieving this token can be found below in the Authentication section. You may pass this token in requests either via the the X-Token header or via basic authentication (base64 encoded) in Authorization header.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from ProvisioningPortal.api_client import ApiClient


class VPSAApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add_proxy_vc_to_vpsa_object_storage(self, vpsa_id, add_proxy_vc_to_vpsa_object_storage, **kwargs):  # noqa: E501
        """add_proxy_vc_to_vpsa_object_storage  # noqa: E501

        Add a proxy Virtual Controller to a VPSA Object storage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_proxy_vc_to_vpsa_object_storage(vpsa_id, add_proxy_vc_to_vpsa_object_storage, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :param AddProxyVcToVpsaObjectStorage add_proxy_vc_to_vpsa_object_storage: (required)
        :return: InlineResponse20035
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_proxy_vc_to_vpsa_object_storage_with_http_info(vpsa_id, add_proxy_vc_to_vpsa_object_storage, **kwargs)  # noqa: E501
        else:
            (data) = self.add_proxy_vc_to_vpsa_object_storage_with_http_info(vpsa_id, add_proxy_vc_to_vpsa_object_storage, **kwargs)  # noqa: E501
            return data

    def add_proxy_vc_to_vpsa_object_storage_with_http_info(self, vpsa_id, add_proxy_vc_to_vpsa_object_storage, **kwargs):  # noqa: E501
        """add_proxy_vc_to_vpsa_object_storage  # noqa: E501

        Add a proxy Virtual Controller to a VPSA Object storage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_proxy_vc_to_vpsa_object_storage_with_http_info(vpsa_id, add_proxy_vc_to_vpsa_object_storage, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :param AddProxyVcToVpsaObjectStorage add_proxy_vc_to_vpsa_object_storage: (required)
        :return: InlineResponse20035
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['vpsa_id', 'add_proxy_vc_to_vpsa_object_storage']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_proxy_vc_to_vpsa_object_storage" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'vpsa_id' is set
        if self.api_client.client_side_validation and ('vpsa_id' not in params or
                                                       params['vpsa_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vpsa_id` when calling `add_proxy_vc_to_vpsa_object_storage`")  # noqa: E501
        # verify the required parameter 'add_proxy_vc_to_vpsa_object_storage' is set
        if self.api_client.client_side_validation and ('add_proxy_vc_to_vpsa_object_storage' not in params or
                                                       params['add_proxy_vc_to_vpsa_object_storage'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `add_proxy_vc_to_vpsa_object_storage` when calling `add_proxy_vc_to_vpsa_object_storage`")  # noqa: E501

        if self.api_client.client_side_validation and ('vpsa_id' in params and not re.search(r'vsa-[0-9a-z]+|[0-9]+', params['vpsa_id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `vpsa_id` when calling `add_proxy_vc_to_vpsa_object_storage`, must conform to the pattern `/vsa-[0-9a-z]+|[0-9]+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'vpsa_id' in params:
            path_params['vpsa_id'] = params['vpsa_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_proxy_vc_to_vpsa_object_storage' in params:
            body_params = params['add_proxy_vc_to_vpsa_object_storage']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vpsas/{vpsa_id}/proxy_vcs/add.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20035',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def add_storage_policy_to_vpsa_object_storage(self, vpsa_id, add_storage_policy_to_vpsa_object_storage, **kwargs):  # noqa: E501
        """add_storage_policy_to_vpsa_object_storage  # noqa: E501

        Add a storage policy to a VPSA object storage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_storage_policy_to_vpsa_object_storage(vpsa_id, add_storage_policy_to_vpsa_object_storage, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :param AddStoragePolicyToVpsaObjectStorage add_storage_policy_to_vpsa_object_storage: (required)
        :return: Default
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_storage_policy_to_vpsa_object_storage_with_http_info(vpsa_id, add_storage_policy_to_vpsa_object_storage, **kwargs)  # noqa: E501
        else:
            (data) = self.add_storage_policy_to_vpsa_object_storage_with_http_info(vpsa_id, add_storage_policy_to_vpsa_object_storage, **kwargs)  # noqa: E501
            return data

    def add_storage_policy_to_vpsa_object_storage_with_http_info(self, vpsa_id, add_storage_policy_to_vpsa_object_storage, **kwargs):  # noqa: E501
        """add_storage_policy_to_vpsa_object_storage  # noqa: E501

        Add a storage policy to a VPSA object storage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_storage_policy_to_vpsa_object_storage_with_http_info(vpsa_id, add_storage_policy_to_vpsa_object_storage, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :param AddStoragePolicyToVpsaObjectStorage add_storage_policy_to_vpsa_object_storage: (required)
        :return: Default
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['vpsa_id', 'add_storage_policy_to_vpsa_object_storage']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_storage_policy_to_vpsa_object_storage" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'vpsa_id' is set
        if self.api_client.client_side_validation and ('vpsa_id' not in params or
                                                       params['vpsa_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vpsa_id` when calling `add_storage_policy_to_vpsa_object_storage`")  # noqa: E501
        # verify the required parameter 'add_storage_policy_to_vpsa_object_storage' is set
        if self.api_client.client_side_validation and ('add_storage_policy_to_vpsa_object_storage' not in params or
                                                       params['add_storage_policy_to_vpsa_object_storage'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `add_storage_policy_to_vpsa_object_storage` when calling `add_storage_policy_to_vpsa_object_storage`")  # noqa: E501

        if self.api_client.client_side_validation and ('vpsa_id' in params and not re.search(r'vsa-[0-9a-z]+|[0-9]+', params['vpsa_id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `vpsa_id` when calling `add_storage_policy_to_vpsa_object_storage`, must conform to the pattern `/vsa-[0-9a-z]+|[0-9]+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'vpsa_id' in params:
            path_params['vpsa_id'] = params['vpsa_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_storage_policy_to_vpsa_object_storage' in params:
            body_params = params['add_storage_policy_to_vpsa_object_storage']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vpsas/{vpsa_id}/storage_policy.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Default',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def add_storage_to_vpsa(self, vpsa_id, add_storage_to_vpsa, **kwargs):  # noqa: E501
        """add_storage_to_vpsa  # noqa: E501

        Add additional storage to a VPSA.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_storage_to_vpsa(vpsa_id, add_storage_to_vpsa, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :param AddStorageToVpsa add_storage_to_vpsa: (required)
        :return: InlineResponse20031
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_storage_to_vpsa_with_http_info(vpsa_id, add_storage_to_vpsa, **kwargs)  # noqa: E501
        else:
            (data) = self.add_storage_to_vpsa_with_http_info(vpsa_id, add_storage_to_vpsa, **kwargs)  # noqa: E501
            return data

    def add_storage_to_vpsa_with_http_info(self, vpsa_id, add_storage_to_vpsa, **kwargs):  # noqa: E501
        """add_storage_to_vpsa  # noqa: E501

        Add additional storage to a VPSA.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_storage_to_vpsa_with_http_info(vpsa_id, add_storage_to_vpsa, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :param AddStorageToVpsa add_storage_to_vpsa: (required)
        :return: InlineResponse20031
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['vpsa_id', 'add_storage_to_vpsa']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_storage_to_vpsa" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'vpsa_id' is set
        if self.api_client.client_side_validation and ('vpsa_id' not in params or
                                                       params['vpsa_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vpsa_id` when calling `add_storage_to_vpsa`")  # noqa: E501
        # verify the required parameter 'add_storage_to_vpsa' is set
        if self.api_client.client_side_validation and ('add_storage_to_vpsa' not in params or
                                                       params['add_storage_to_vpsa'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `add_storage_to_vpsa` when calling `add_storage_to_vpsa`")  # noqa: E501

        if self.api_client.client_side_validation and ('vpsa_id' in params and not re.search(r'vsa-[0-9a-z]+|[0-9]+', params['vpsa_id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `vpsa_id` when calling `add_storage_to_vpsa`, must conform to the pattern `/vsa-[0-9a-z]+|[0-9]+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'vpsa_id' in params:
            path_params['vpsa_id'] = params['vpsa_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_storage_to_vpsa' in params:
            body_params = params['add_storage_to_vpsa']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vpsas/{vpsa_id}/drives.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20031',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def add_virtual_network_vpsa(self, vpsa_id, add_virtual_network_vpsa, **kwargs):  # noqa: E501
        """add_virtual_network_vpsa  # noqa: E501

        Add a Virtual Network Interface to a VPSA.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_virtual_network_vpsa(vpsa_id, add_virtual_network_vpsa, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :param AddVirtualNetworkVpsa add_virtual_network_vpsa: (required)
        :return: InlineResponse20039
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.add_virtual_network_vpsa_with_http_info(vpsa_id, add_virtual_network_vpsa, **kwargs)  # noqa: E501
        else:
            (data) = self.add_virtual_network_vpsa_with_http_info(vpsa_id, add_virtual_network_vpsa, **kwargs)  # noqa: E501
            return data

    def add_virtual_network_vpsa_with_http_info(self, vpsa_id, add_virtual_network_vpsa, **kwargs):  # noqa: E501
        """add_virtual_network_vpsa  # noqa: E501

        Add a Virtual Network Interface to a VPSA.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.add_virtual_network_vpsa_with_http_info(vpsa_id, add_virtual_network_vpsa, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :param AddVirtualNetworkVpsa add_virtual_network_vpsa: (required)
        :return: InlineResponse20039
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['vpsa_id', 'add_virtual_network_vpsa']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method add_virtual_network_vpsa" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'vpsa_id' is set
        if self.api_client.client_side_validation and ('vpsa_id' not in params or
                                                       params['vpsa_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vpsa_id` when calling `add_virtual_network_vpsa`")  # noqa: E501
        # verify the required parameter 'add_virtual_network_vpsa' is set
        if self.api_client.client_side_validation and ('add_virtual_network_vpsa' not in params or
                                                       params['add_virtual_network_vpsa'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `add_virtual_network_vpsa` when calling `add_virtual_network_vpsa`")  # noqa: E501

        if self.api_client.client_side_validation and ('vpsa_id' in params and not re.search(r'vsa-[0-9a-z]+|[0-9]+', params['vpsa_id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `vpsa_id` when calling `add_virtual_network_vpsa`, must conform to the pattern `/vsa-[0-9a-z]+|[0-9]+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'vpsa_id' in params:
            path_params['vpsa_id'] = params['vpsa_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_virtual_network_vpsa' in params:
            body_params = params['add_virtual_network_vpsa']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vpsas/{vpsa_id}/add_vni.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20039',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def assign_public_ip_vpsa(self, vpsa_id, **kwargs):  # noqa: E501
        """assign_public_ip_vpsa  # noqa: E501

        Assign a public IP to a VPSA.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assign_public_ip_vpsa(vpsa_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :return: InlineResponse20036
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.assign_public_ip_vpsa_with_http_info(vpsa_id, **kwargs)  # noqa: E501
        else:
            (data) = self.assign_public_ip_vpsa_with_http_info(vpsa_id, **kwargs)  # noqa: E501
            return data

    def assign_public_ip_vpsa_with_http_info(self, vpsa_id, **kwargs):  # noqa: E501
        """assign_public_ip_vpsa  # noqa: E501

        Assign a public IP to a VPSA.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assign_public_ip_vpsa_with_http_info(vpsa_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :return: InlineResponse20036
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['vpsa_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method assign_public_ip_vpsa" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'vpsa_id' is set
        if self.api_client.client_side_validation and ('vpsa_id' not in params or
                                                       params['vpsa_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vpsa_id` when calling `assign_public_ip_vpsa`")  # noqa: E501

        if self.api_client.client_side_validation and ('vpsa_id' in params and not re.search(r'vsa-[0-9a-z]+|[0-9]+', params['vpsa_id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `vpsa_id` when calling `assign_public_ip_vpsa`, must conform to the pattern `/vsa-[0-9a-z]+|[0-9]+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'vpsa_id' in params:
            path_params['vpsa_id'] = params['vpsa_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vpsas/{vpsa_id}/public_ip.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20036',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_vpsa_flash_cache_capacity(self, vpsa_id, change_vpsa_flash_cache_capacity, **kwargs):  # noqa: E501
        """change_vpsa_flash_cache_capacity  # noqa: E501

        Change a VPSA's extended flash cache capacity.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_vpsa_flash_cache_capacity(vpsa_id, change_vpsa_flash_cache_capacity, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :param ChangeVpsaFlashCacheCapacity change_vpsa_flash_cache_capacity: (required)
        :return: InlineResponse20030
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.change_vpsa_flash_cache_capacity_with_http_info(vpsa_id, change_vpsa_flash_cache_capacity, **kwargs)  # noqa: E501
        else:
            (data) = self.change_vpsa_flash_cache_capacity_with_http_info(vpsa_id, change_vpsa_flash_cache_capacity, **kwargs)  # noqa: E501
            return data

    def change_vpsa_flash_cache_capacity_with_http_info(self, vpsa_id, change_vpsa_flash_cache_capacity, **kwargs):  # noqa: E501
        """change_vpsa_flash_cache_capacity  # noqa: E501

        Change a VPSA's extended flash cache capacity.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_vpsa_flash_cache_capacity_with_http_info(vpsa_id, change_vpsa_flash_cache_capacity, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :param ChangeVpsaFlashCacheCapacity change_vpsa_flash_cache_capacity: (required)
        :return: InlineResponse20030
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['vpsa_id', 'change_vpsa_flash_cache_capacity']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_vpsa_flash_cache_capacity" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'vpsa_id' is set
        if self.api_client.client_side_validation and ('vpsa_id' not in params or
                                                       params['vpsa_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vpsa_id` when calling `change_vpsa_flash_cache_capacity`")  # noqa: E501
        # verify the required parameter 'change_vpsa_flash_cache_capacity' is set
        if self.api_client.client_side_validation and ('change_vpsa_flash_cache_capacity' not in params or
                                                       params['change_vpsa_flash_cache_capacity'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `change_vpsa_flash_cache_capacity` when calling `change_vpsa_flash_cache_capacity`")  # noqa: E501

        if self.api_client.client_side_validation and ('vpsa_id' in params and not re.search(r'vsa-[0-9a-z]+|[0-9]+', params['vpsa_id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `vpsa_id` when calling `change_vpsa_flash_cache_capacity`, must conform to the pattern `/vsa-[0-9a-z]+|[0-9]+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'vpsa_id' in params:
            path_params['vpsa_id'] = params['vpsa_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'change_vpsa_flash_cache_capacity' in params:
            body_params = params['change_vpsa_flash_cache_capacity']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vpsas/{vpsa_id}/cache.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20030',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def change_vpsa_zadara_engine(self, vpsa_id, change_vpsa_zadara_engine, **kwargs):  # noqa: E501
        """change_vpsa_zadara_engine  # noqa: E501

        Change a VPSA's Zadara Engine.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_vpsa_zadara_engine(vpsa_id, change_vpsa_zadara_engine, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :param ChangeVpsaZadaraEngine change_vpsa_zadara_engine: (required)
        :return: InlineResponse20029
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.change_vpsa_zadara_engine_with_http_info(vpsa_id, change_vpsa_zadara_engine, **kwargs)  # noqa: E501
        else:
            (data) = self.change_vpsa_zadara_engine_with_http_info(vpsa_id, change_vpsa_zadara_engine, **kwargs)  # noqa: E501
            return data

    def change_vpsa_zadara_engine_with_http_info(self, vpsa_id, change_vpsa_zadara_engine, **kwargs):  # noqa: E501
        """change_vpsa_zadara_engine  # noqa: E501

        Change a VPSA's Zadara Engine.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.change_vpsa_zadara_engine_with_http_info(vpsa_id, change_vpsa_zadara_engine, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :param ChangeVpsaZadaraEngine change_vpsa_zadara_engine: (required)
        :return: InlineResponse20029
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['vpsa_id', 'change_vpsa_zadara_engine']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method change_vpsa_zadara_engine" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'vpsa_id' is set
        if self.api_client.client_side_validation and ('vpsa_id' not in params or
                                                       params['vpsa_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vpsa_id` when calling `change_vpsa_zadara_engine`")  # noqa: E501
        # verify the required parameter 'change_vpsa_zadara_engine' is set
        if self.api_client.client_side_validation and ('change_vpsa_zadara_engine' not in params or
                                                       params['change_vpsa_zadara_engine'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `change_vpsa_zadara_engine` when calling `change_vpsa_zadara_engine`")  # noqa: E501

        if self.api_client.client_side_validation and ('vpsa_id' in params and not re.search(r'vsa-[0-9a-z]+|[0-9]+', params['vpsa_id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `vpsa_id` when calling `change_vpsa_zadara_engine`, must conform to the pattern `/vsa-[0-9a-z]+|[0-9]+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'vpsa_id' in params:
            path_params['vpsa_id'] = params['vpsa_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'change_vpsa_zadara_engine' in params:
            body_params = params['change_vpsa_zadara_engine']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vpsas/{vpsa_id}/engine.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20029',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_object_storage_account(self, vpsa_id, create_object_storage_account, **kwargs):  # noqa: E501
        """create_object_storage_account  # noqa: E501

        Create a new object storage account.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_object_storage_account(vpsa_id, create_object_storage_account, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :param CreateObjectStorageAccount create_object_storage_account: (required)
        :return: InlineResponse20048
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_object_storage_account_with_http_info(vpsa_id, create_object_storage_account, **kwargs)  # noqa: E501
        else:
            (data) = self.create_object_storage_account_with_http_info(vpsa_id, create_object_storage_account, **kwargs)  # noqa: E501
            return data

    def create_object_storage_account_with_http_info(self, vpsa_id, create_object_storage_account, **kwargs):  # noqa: E501
        """create_object_storage_account  # noqa: E501

        Create a new object storage account.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_object_storage_account_with_http_info(vpsa_id, create_object_storage_account, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :param CreateObjectStorageAccount create_object_storage_account: (required)
        :return: InlineResponse20048
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['vpsa_id', 'create_object_storage_account']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_object_storage_account" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'vpsa_id' is set
        if self.api_client.client_side_validation and ('vpsa_id' not in params or
                                                       params['vpsa_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vpsa_id` when calling `create_object_storage_account`")  # noqa: E501
        # verify the required parameter 'create_object_storage_account' is set
        if self.api_client.client_side_validation and ('create_object_storage_account' not in params or
                                                       params['create_object_storage_account'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `create_object_storage_account` when calling `create_object_storage_account`")  # noqa: E501

        if self.api_client.client_side_validation and ('vpsa_id' in params and not re.search(r'vsa-[0-9a-z]+|[0-9]+', params['vpsa_id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `vpsa_id` when calling `create_object_storage_account`, must conform to the pattern `/vsa-[0-9a-z]+|[0-9]+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'vpsa_id' in params:
            path_params['vpsa_id'] = params['vpsa_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_object_storage_account' in params:
            body_params = params['create_object_storage_account']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vpsas/{vpsa_id}/accounts.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20048',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_vpsa(self, create_vpsa, **kwargs):  # noqa: E501
        """create_vpsa  # noqa: E501

        Create a VPSA Storage Array or VPSA Object Storage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_vpsa(create_vpsa, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateVpsa create_vpsa: (required)
        :return: InlineResponse20026
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_vpsa_with_http_info(create_vpsa, **kwargs)  # noqa: E501
        else:
            (data) = self.create_vpsa_with_http_info(create_vpsa, **kwargs)  # noqa: E501
            return data

    def create_vpsa_with_http_info(self, create_vpsa, **kwargs):  # noqa: E501
        """create_vpsa  # noqa: E501

        Create a VPSA Storage Array or VPSA Object Storage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_vpsa_with_http_info(create_vpsa, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateVpsa create_vpsa: (required)
        :return: InlineResponse20026
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['create_vpsa']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_vpsa" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'create_vpsa' is set
        if self.api_client.client_side_validation and ('create_vpsa' not in params or
                                                       params['create_vpsa'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `create_vpsa` when calling `create_vpsa`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_vpsa' in params:
            body_params = params['create_vpsa']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vpsas.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20026',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_vpsa(self, vpsa_id, **kwargs):  # noqa: E501
        """delete_vpsa  # noqa: E501

        Delete a VPSA.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_vpsa(vpsa_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :return: InlineResponse20028
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_vpsa_with_http_info(vpsa_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_vpsa_with_http_info(vpsa_id, **kwargs)  # noqa: E501
            return data

    def delete_vpsa_with_http_info(self, vpsa_id, **kwargs):  # noqa: E501
        """delete_vpsa  # noqa: E501

        Delete a VPSA.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_vpsa_with_http_info(vpsa_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :return: InlineResponse20028
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['vpsa_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_vpsa" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'vpsa_id' is set
        if self.api_client.client_side_validation and ('vpsa_id' not in params or
                                                       params['vpsa_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vpsa_id` when calling `delete_vpsa`")  # noqa: E501

        if self.api_client.client_side_validation and ('vpsa_id' in params and not re.search(r'vsa-[0-9a-z]+|[0-9]+', params['vpsa_id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `vpsa_id` when calling `delete_vpsa`, must conform to the pattern `/vsa-[0-9a-z]+|[0-9]+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'vpsa_id' in params:
            path_params['vpsa_id'] = params['vpsa_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vpsas/{vpsa_id}.json', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20028',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def disable_object_account_servce_from_vpsa_object_storage(self, vpsa_id, **kwargs):  # noqa: E501
        """disable_object_account_servce_from_vpsa_object_storage  # noqa: E501

        Disable object account service from an existing VPSA Object Storage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.disable_object_account_servce_from_vpsa_object_storage(vpsa_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :return: InlineResponse20046
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.disable_object_account_servce_from_vpsa_object_storage_with_http_info(vpsa_id, **kwargs)  # noqa: E501
        else:
            (data) = self.disable_object_account_servce_from_vpsa_object_storage_with_http_info(vpsa_id, **kwargs)  # noqa: E501
            return data

    def disable_object_account_servce_from_vpsa_object_storage_with_http_info(self, vpsa_id, **kwargs):  # noqa: E501
        """disable_object_account_servce_from_vpsa_object_storage  # noqa: E501

        Disable object account service from an existing VPSA Object Storage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.disable_object_account_servce_from_vpsa_object_storage_with_http_info(vpsa_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :return: InlineResponse20046
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['vpsa_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method disable_object_account_servce_from_vpsa_object_storage" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'vpsa_id' is set
        if self.api_client.client_side_validation and ('vpsa_id' not in params or
                                                       params['vpsa_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vpsa_id` when calling `disable_object_account_servce_from_vpsa_object_storage`")  # noqa: E501

        if self.api_client.client_side_validation and ('vpsa_id' in params and not re.search(r'vsa-[0-9a-z]+|[0-9]+', params['vpsa_id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `vpsa_id` when calling `disable_object_account_servce_from_vpsa_object_storage`, must conform to the pattern `/vsa-[0-9a-z]+|[0-9]+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'vpsa_id' in params:
            path_params['vpsa_id'] = params['vpsa_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vpsas/{vpsa_id}/public_zios.json', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20046',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def disables_data_reduction_bundle_on_flash_vpsa(self, vpsa_id, **kwargs):  # noqa: E501
        """disables_data_reduction_bundle_on_flash_vpsa  # noqa: E501

        Disables data reduction bundle on a Flash VPSA.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.disables_data_reduction_bundle_on_flash_vpsa(vpsa_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :return: InlineResponse20042
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.disables_data_reduction_bundle_on_flash_vpsa_with_http_info(vpsa_id, **kwargs)  # noqa: E501
        else:
            (data) = self.disables_data_reduction_bundle_on_flash_vpsa_with_http_info(vpsa_id, **kwargs)  # noqa: E501
            return data

    def disables_data_reduction_bundle_on_flash_vpsa_with_http_info(self, vpsa_id, **kwargs):  # noqa: E501
        """disables_data_reduction_bundle_on_flash_vpsa  # noqa: E501

        Disables data reduction bundle on a Flash VPSA.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.disables_data_reduction_bundle_on_flash_vpsa_with_http_info(vpsa_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :return: InlineResponse20042
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['vpsa_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method disables_data_reduction_bundle_on_flash_vpsa" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'vpsa_id' is set
        if self.api_client.client_side_validation and ('vpsa_id' not in params or
                                                       params['vpsa_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vpsa_id` when calling `disables_data_reduction_bundle_on_flash_vpsa`")  # noqa: E501

        if self.api_client.client_side_validation and ('vpsa_id' in params and not re.search(r'vsa-[0-9a-z]+|[0-9]+', params['vpsa_id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `vpsa_id` when calling `disables_data_reduction_bundle_on_flash_vpsa`, must conform to the pattern `/vsa-[0-9a-z]+|[0-9]+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'vpsa_id' in params:
            path_params['vpsa_id'] = params['vpsa_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vpsas/{vpsa_id}/disable_data_reduction_bundle.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20042',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def enable_object_account_servce_for_vpsa_object_storage(self, vpsa_id, enable_object_account, **kwargs):  # noqa: E501
        """enable_object_account_servce_for_vpsa_object_storage  # noqa: E501

        Enable object account service for an existing VPSA Object Storage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.enable_object_account_servce_for_vpsa_object_storage(vpsa_id, enable_object_account, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :param EnableObjectAccount enable_object_account: (required)
        :return: InlineResponse20045
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.enable_object_account_servce_for_vpsa_object_storage_with_http_info(vpsa_id, enable_object_account, **kwargs)  # noqa: E501
        else:
            (data) = self.enable_object_account_servce_for_vpsa_object_storage_with_http_info(vpsa_id, enable_object_account, **kwargs)  # noqa: E501
            return data

    def enable_object_account_servce_for_vpsa_object_storage_with_http_info(self, vpsa_id, enable_object_account, **kwargs):  # noqa: E501
        """enable_object_account_servce_for_vpsa_object_storage  # noqa: E501

        Enable object account service for an existing VPSA Object Storage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.enable_object_account_servce_for_vpsa_object_storage_with_http_info(vpsa_id, enable_object_account, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :param EnableObjectAccount enable_object_account: (required)
        :return: InlineResponse20045
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['vpsa_id', 'enable_object_account']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method enable_object_account_servce_for_vpsa_object_storage" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'vpsa_id' is set
        if self.api_client.client_side_validation and ('vpsa_id' not in params or
                                                       params['vpsa_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vpsa_id` when calling `enable_object_account_servce_for_vpsa_object_storage`")  # noqa: E501
        # verify the required parameter 'enable_object_account' is set
        if self.api_client.client_side_validation and ('enable_object_account' not in params or
                                                       params['enable_object_account'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `enable_object_account` when calling `enable_object_account_servce_for_vpsa_object_storage`")  # noqa: E501

        if self.api_client.client_side_validation and ('vpsa_id' in params and not re.search(r'vsa-[0-9a-z]+|[0-9]+', params['vpsa_id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `vpsa_id` when calling `enable_object_account_servce_for_vpsa_object_storage`, must conform to the pattern `/vsa-[0-9a-z]+|[0-9]+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'vpsa_id' in params:
            path_params['vpsa_id'] = params['vpsa_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'enable_object_account' in params:
            body_params = params['enable_object_account']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vpsas/{vpsa_id}/public_zios.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20045',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def enables_data_reduction_bundle_on_flash_vpsa(self, vpsa_id, **kwargs):  # noqa: E501
        """enables_data_reduction_bundle_on_flash_vpsa  # noqa: E501

        Enables data reduction bundle on a Flash VPSA.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.enables_data_reduction_bundle_on_flash_vpsa(vpsa_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :return: InlineResponse20041
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.enables_data_reduction_bundle_on_flash_vpsa_with_http_info(vpsa_id, **kwargs)  # noqa: E501
        else:
            (data) = self.enables_data_reduction_bundle_on_flash_vpsa_with_http_info(vpsa_id, **kwargs)  # noqa: E501
            return data

    def enables_data_reduction_bundle_on_flash_vpsa_with_http_info(self, vpsa_id, **kwargs):  # noqa: E501
        """enables_data_reduction_bundle_on_flash_vpsa  # noqa: E501

        Enables data reduction bundle on a Flash VPSA.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.enables_data_reduction_bundle_on_flash_vpsa_with_http_info(vpsa_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :return: InlineResponse20041
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['vpsa_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method enables_data_reduction_bundle_on_flash_vpsa" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'vpsa_id' is set
        if self.api_client.client_side_validation and ('vpsa_id' not in params or
                                                       params['vpsa_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vpsa_id` when calling `enables_data_reduction_bundle_on_flash_vpsa`")  # noqa: E501

        if self.api_client.client_side_validation and ('vpsa_id' in params and not re.search(r'vsa-[0-9a-z]+|[0-9]+', params['vpsa_id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `vpsa_id` when calling `enables_data_reduction_bundle_on_flash_vpsa`, must conform to the pattern `/vsa-[0-9a-z]+|[0-9]+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'vpsa_id' in params:
            path_params['vpsa_id'] = params['vpsa_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vpsas/{vpsa_id}/enable_data_reduction.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20041',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_object_account_servce_for_vpsa_object_storage(self, vpsa_id, **kwargs):  # noqa: E501
        """get_object_account_servce_for_vpsa_object_storage  # noqa: E501

        Get object account service for an existing VPSA Object Storage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_object_account_servce_for_vpsa_object_storage(vpsa_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :return: InlineResponse20043
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_object_account_servce_for_vpsa_object_storage_with_http_info(vpsa_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_object_account_servce_for_vpsa_object_storage_with_http_info(vpsa_id, **kwargs)  # noqa: E501
            return data

    def get_object_account_servce_for_vpsa_object_storage_with_http_info(self, vpsa_id, **kwargs):  # noqa: E501
        """get_object_account_servce_for_vpsa_object_storage  # noqa: E501

        Get object account service for an existing VPSA Object Storage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_object_account_servce_for_vpsa_object_storage_with_http_info(vpsa_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :return: InlineResponse20043
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['vpsa_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_object_account_servce_for_vpsa_object_storage" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'vpsa_id' is set
        if self.api_client.client_side_validation and ('vpsa_id' not in params or
                                                       params['vpsa_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vpsa_id` when calling `get_object_account_servce_for_vpsa_object_storage`")  # noqa: E501

        if self.api_client.client_side_validation and ('vpsa_id' in params and not re.search(r'vsa-[0-9a-z]+|[0-9]+', params['vpsa_id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `vpsa_id` when calling `get_object_account_servce_for_vpsa_object_storage`, must conform to the pattern `/vsa-[0-9a-z]+|[0-9]+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'vpsa_id' in params:
            path_params['vpsa_id'] = params['vpsa_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vpsas/{vpsa_id}/public_zios.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20043',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_object_storage_account_info(self, vpsa_id, account_id, **kwargs):  # noqa: E501
        """get_object_storage_account_info  # noqa: E501

        Get an object storage account details.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_object_storage_account_info(vpsa_id, account_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :param str account_id: (required)
        :return: InlineResponse20049
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_object_storage_account_info_with_http_info(vpsa_id, account_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_object_storage_account_info_with_http_info(vpsa_id, account_id, **kwargs)  # noqa: E501
            return data

    def get_object_storage_account_info_with_http_info(self, vpsa_id, account_id, **kwargs):  # noqa: E501
        """get_object_storage_account_info  # noqa: E501

        Get an object storage account details.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_object_storage_account_info_with_http_info(vpsa_id, account_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :param str account_id: (required)
        :return: InlineResponse20049
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['vpsa_id', 'account_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_object_storage_account_info" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'vpsa_id' is set
        if self.api_client.client_side_validation and ('vpsa_id' not in params or
                                                       params['vpsa_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vpsa_id` when calling `get_object_storage_account_info`")  # noqa: E501
        # verify the required parameter 'account_id' is set
        if self.api_client.client_side_validation and ('account_id' not in params or
                                                       params['account_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `account_id` when calling `get_object_storage_account_info`")  # noqa: E501

        if self.api_client.client_side_validation and ('vpsa_id' in params and not re.search(r'vsa-[0-9a-z]+|[0-9]+', params['vpsa_id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `vpsa_id` when calling `get_object_storage_account_info`, must conform to the pattern `/vsa-[0-9a-z]+|[0-9]+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'vpsa_id' in params:
            path_params['vpsa_id'] = params['vpsa_id']  # noqa: E501
        if 'account_id' in params:
            path_params['account_id'] = params['account_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vpsas/{vpsa_id}/accounts/{account_id}.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20049',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_vpsa_information(self, vpsa_id, **kwargs):  # noqa: E501
        """get_vpsa_information  # noqa: E501

        Retrieve information about a single VPSA.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_vpsa_information(vpsa_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :return: InlineResponse20027
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_vpsa_information_with_http_info(vpsa_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_vpsa_information_with_http_info(vpsa_id, **kwargs)  # noqa: E501
            return data

    def get_vpsa_information_with_http_info(self, vpsa_id, **kwargs):  # noqa: E501
        """get_vpsa_information  # noqa: E501

        Retrieve information about a single VPSA.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_vpsa_information_with_http_info(vpsa_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :return: InlineResponse20027
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['vpsa_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_vpsa_information" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'vpsa_id' is set
        if self.api_client.client_side_validation and ('vpsa_id' not in params or
                                                       params['vpsa_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vpsa_id` when calling `get_vpsa_information`")  # noqa: E501

        if self.api_client.client_side_validation and ('vpsa_id' in params and not re.search(r'vsa-[0-9a-z]+|[0-9]+', params['vpsa_id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `vpsa_id` when calling `get_vpsa_information`, must conform to the pattern `/vsa-[0-9a-z]+|[0-9]+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'vpsa_id' in params:
            path_params['vpsa_id'] = params['vpsa_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vpsas/{vpsa_id}.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20027',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_vpsas_info(self, **kwargs):  # noqa: E501
        """get_vpsas_info  # noqa: E501

        Retrieve information about all of your VPSAs.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_vpsas_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse20025
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_vpsas_info_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_vpsas_info_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_vpsas_info_with_http_info(self, **kwargs):  # noqa: E501
        """get_vpsas_info  # noqa: E501

        Retrieve information about all of your VPSAs.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_vpsas_info_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: InlineResponse20025
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_vpsas_info" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vpsas.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20025',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def hibernate_vpsa(self, vpsa_id, **kwargs):  # noqa: E501
        """hibernate_vpsa  # noqa: E501

        Hibernate a VPSA.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.hibernate_vpsa(vpsa_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :return: InlineResponse20032
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.hibernate_vpsa_with_http_info(vpsa_id, **kwargs)  # noqa: E501
        else:
            (data) = self.hibernate_vpsa_with_http_info(vpsa_id, **kwargs)  # noqa: E501
            return data

    def hibernate_vpsa_with_http_info(self, vpsa_id, **kwargs):  # noqa: E501
        """hibernate_vpsa  # noqa: E501

        Hibernate a VPSA.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.hibernate_vpsa_with_http_info(vpsa_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :return: InlineResponse20032
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['vpsa_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method hibernate_vpsa" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'vpsa_id' is set
        if self.api_client.client_side_validation and ('vpsa_id' not in params or
                                                       params['vpsa_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vpsa_id` when calling `hibernate_vpsa`")  # noqa: E501

        if self.api_client.client_side_validation and ('vpsa_id' in params and not re.search(r'vsa-[0-9a-z]+|[0-9]+', params['vpsa_id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `vpsa_id` when calling `hibernate_vpsa`, must conform to the pattern `/vsa-[0-9a-z]+|[0-9]+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'vpsa_id' in params:
            path_params['vpsa_id'] = params['vpsa_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vpsas/{vpsa_id}/hibernate.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20032',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_compatible_vni_for_vpsa(self, vpsa_id, **kwargs):  # noqa: E501
        """list_compatible_vni_for_vpsa  # noqa: E501

        Return a list of compatible Virtual Network Interface for a VPSA.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_compatible_vni_for_vpsa(vpsa_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :return: InlineResponse20038
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_compatible_vni_for_vpsa_with_http_info(vpsa_id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_compatible_vni_for_vpsa_with_http_info(vpsa_id, **kwargs)  # noqa: E501
            return data

    def list_compatible_vni_for_vpsa_with_http_info(self, vpsa_id, **kwargs):  # noqa: E501
        """list_compatible_vni_for_vpsa  # noqa: E501

        Return a list of compatible Virtual Network Interface for a VPSA.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_compatible_vni_for_vpsa_with_http_info(vpsa_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :return: InlineResponse20038
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['vpsa_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_compatible_vni_for_vpsa" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'vpsa_id' is set
        if self.api_client.client_side_validation and ('vpsa_id' not in params or
                                                       params['vpsa_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vpsa_id` when calling `list_compatible_vni_for_vpsa`")  # noqa: E501

        if self.api_client.client_side_validation and ('vpsa_id' in params and not re.search(r'vsa-[0-9a-z]+|[0-9]+', params['vpsa_id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `vpsa_id` when calling `list_compatible_vni_for_vpsa`, must conform to the pattern `/vsa-[0-9a-z]+|[0-9]+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'vpsa_id' in params:
            path_params['vpsa_id'] = params['vpsa_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vpsas/{vpsa_id}/compatible_vnis.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20038',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_object_storage_accounts_of_vpsa(self, vpsa_id, **kwargs):  # noqa: E501
        """list_object_storage_accounts_of_vpsa  # noqa: E501

        Get all object storage accounts for a given VPSA Object Storage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_object_storage_accounts_of_vpsa(vpsa_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :return: InlineResponse20047
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_object_storage_accounts_of_vpsa_with_http_info(vpsa_id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_object_storage_accounts_of_vpsa_with_http_info(vpsa_id, **kwargs)  # noqa: E501
            return data

    def list_object_storage_accounts_of_vpsa_with_http_info(self, vpsa_id, **kwargs):  # noqa: E501
        """list_object_storage_accounts_of_vpsa  # noqa: E501

        Get all object storage accounts for a given VPSA Object Storage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_object_storage_accounts_of_vpsa_with_http_info(vpsa_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :return: InlineResponse20047
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['vpsa_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_object_storage_accounts_of_vpsa" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'vpsa_id' is set
        if self.api_client.client_side_validation and ('vpsa_id' not in params or
                                                       params['vpsa_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vpsa_id` when calling `list_object_storage_accounts_of_vpsa`")  # noqa: E501

        if self.api_client.client_side_validation and ('vpsa_id' in params and not re.search(r'vsa-[0-9a-z]+|[0-9]+', params['vpsa_id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `vpsa_id` when calling `list_object_storage_accounts_of_vpsa`, must conform to the pattern `/vsa-[0-9a-z]+|[0-9]+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'vpsa_id' in params:
            path_params['vpsa_id'] = params['vpsa_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vpsas/{vpsa_id}/accounts.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20047',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def maintenance_mode(self, vpsa_id, maintenance_mode, **kwargs):  # noqa: E501
        """maintenance_mode  # noqa: E501

        Enter or exit maintenance mode for VPSA Object Storage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.maintenance_mode(vpsa_id, maintenance_mode, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :param MaintenanceMode maintenance_mode: (required)
        :return: InlineResponse20034
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.maintenance_mode_with_http_info(vpsa_id, maintenance_mode, **kwargs)  # noqa: E501
        else:
            (data) = self.maintenance_mode_with_http_info(vpsa_id, maintenance_mode, **kwargs)  # noqa: E501
            return data

    def maintenance_mode_with_http_info(self, vpsa_id, maintenance_mode, **kwargs):  # noqa: E501
        """maintenance_mode  # noqa: E501

        Enter or exit maintenance mode for VPSA Object Storage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.maintenance_mode_with_http_info(vpsa_id, maintenance_mode, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :param MaintenanceMode maintenance_mode: (required)
        :return: InlineResponse20034
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['vpsa_id', 'maintenance_mode']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method maintenance_mode" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'vpsa_id' is set
        if self.api_client.client_side_validation and ('vpsa_id' not in params or
                                                       params['vpsa_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vpsa_id` when calling `maintenance_mode`")  # noqa: E501
        # verify the required parameter 'maintenance_mode' is set
        if self.api_client.client_side_validation and ('maintenance_mode' not in params or
                                                       params['maintenance_mode'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `maintenance_mode` when calling `maintenance_mode`")  # noqa: E501

        if self.api_client.client_side_validation and ('vpsa_id' in params and not re.search(r'vsa-[0-9a-z]+|[0-9]+', params['vpsa_id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `vpsa_id` when calling `maintenance_mode`, must conform to the pattern `/vsa-[0-9a-z]+|[0-9]+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'vpsa_id' in params:
            path_params['vpsa_id'] = params['vpsa_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'maintenance_mode' in params:
            body_params = params['maintenance_mode']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vpsas/{vpsa_id}/maintenance_mode.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20034',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_account_from_vpsa_object_storage(self, vpsa_id, account_id, **kwargs):  # noqa: E501
        """remove_account_from_vpsa_object_storage  # noqa: E501

        Generates a request to remove an object storage account from a VPSA Object Storage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_account_from_vpsa_object_storage(vpsa_id, account_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :param str account_id: (required)
        :return: InlineResponse20050
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_account_from_vpsa_object_storage_with_http_info(vpsa_id, account_id, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_account_from_vpsa_object_storage_with_http_info(vpsa_id, account_id, **kwargs)  # noqa: E501
            return data

    def remove_account_from_vpsa_object_storage_with_http_info(self, vpsa_id, account_id, **kwargs):  # noqa: E501
        """remove_account_from_vpsa_object_storage  # noqa: E501

        Generates a request to remove an object storage account from a VPSA Object Storage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_account_from_vpsa_object_storage_with_http_info(vpsa_id, account_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :param str account_id: (required)
        :return: InlineResponse20050
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['vpsa_id', 'account_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_account_from_vpsa_object_storage" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'vpsa_id' is set
        if self.api_client.client_side_validation and ('vpsa_id' not in params or
                                                       params['vpsa_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vpsa_id` when calling `remove_account_from_vpsa_object_storage`")  # noqa: E501
        # verify the required parameter 'account_id' is set
        if self.api_client.client_side_validation and ('account_id' not in params or
                                                       params['account_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `account_id` when calling `remove_account_from_vpsa_object_storage`")  # noqa: E501

        if self.api_client.client_side_validation and ('vpsa_id' in params and not re.search(r'vsa-[0-9a-z]+|[0-9]+', params['vpsa_id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `vpsa_id` when calling `remove_account_from_vpsa_object_storage`, must conform to the pattern `/vsa-[0-9a-z]+|[0-9]+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'vpsa_id' in params:
            path_params['vpsa_id'] = params['vpsa_id']  # noqa: E501
        if 'account_id' in params:
            path_params['account_id'] = params['account_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vpsas/{vpsa_id}/accounts/{account_id}.json', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20050',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_vni_from_vpsa(self, vpsa_id, remove_vni_from_vpsa, **kwargs):  # noqa: E501
        """remove_vni_from_vpsa  # noqa: E501

        Remove a Virtual Network Interface from a VPSA.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_vni_from_vpsa(vpsa_id, remove_vni_from_vpsa, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :param RemoveVniFromVpsa remove_vni_from_vpsa: (required)
        :return: InlineResponse20040
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_vni_from_vpsa_with_http_info(vpsa_id, remove_vni_from_vpsa, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_vni_from_vpsa_with_http_info(vpsa_id, remove_vni_from_vpsa, **kwargs)  # noqa: E501
            return data

    def remove_vni_from_vpsa_with_http_info(self, vpsa_id, remove_vni_from_vpsa, **kwargs):  # noqa: E501
        """remove_vni_from_vpsa  # noqa: E501

        Remove a Virtual Network Interface from a VPSA.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_vni_from_vpsa_with_http_info(vpsa_id, remove_vni_from_vpsa, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :param RemoveVniFromVpsa remove_vni_from_vpsa: (required)
        :return: InlineResponse20040
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['vpsa_id', 'remove_vni_from_vpsa']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_vni_from_vpsa" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'vpsa_id' is set
        if self.api_client.client_side_validation and ('vpsa_id' not in params or
                                                       params['vpsa_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vpsa_id` when calling `remove_vni_from_vpsa`")  # noqa: E501
        # verify the required parameter 'remove_vni_from_vpsa' is set
        if self.api_client.client_side_validation and ('remove_vni_from_vpsa' not in params or
                                                       params['remove_vni_from_vpsa'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `remove_vni_from_vpsa` when calling `remove_vni_from_vpsa`")  # noqa: E501

        if self.api_client.client_side_validation and ('vpsa_id' in params and not re.search(r'vsa-[0-9a-z]+|[0-9]+', params['vpsa_id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `vpsa_id` when calling `remove_vni_from_vpsa`, must conform to the pattern `/vsa-[0-9a-z]+|[0-9]+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'vpsa_id' in params:
            path_params['vpsa_id'] = params['vpsa_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'remove_vni_from_vpsa' in params:
            body_params = params['remove_vni_from_vpsa']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vpsas/{vpsa_id}/remove_vni.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20040',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def remove_vpsa_public_ip(self, vpsa_id, **kwargs):  # noqa: E501
        """remove_vpsa_public_ip  # noqa: E501

        Remove a public IP from a VPSA.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_vpsa_public_ip(vpsa_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :return: InlineResponse20037
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.remove_vpsa_public_ip_with_http_info(vpsa_id, **kwargs)  # noqa: E501
        else:
            (data) = self.remove_vpsa_public_ip_with_http_info(vpsa_id, **kwargs)  # noqa: E501
            return data

    def remove_vpsa_public_ip_with_http_info(self, vpsa_id, **kwargs):  # noqa: E501
        """remove_vpsa_public_ip  # noqa: E501

        Remove a public IP from a VPSA.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.remove_vpsa_public_ip_with_http_info(vpsa_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :return: InlineResponse20037
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['vpsa_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method remove_vpsa_public_ip" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'vpsa_id' is set
        if self.api_client.client_side_validation and ('vpsa_id' not in params or
                                                       params['vpsa_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vpsa_id` when calling `remove_vpsa_public_ip`")  # noqa: E501

        if self.api_client.client_side_validation and ('vpsa_id' in params and not re.search(r'vsa-[0-9a-z]+|[0-9]+', params['vpsa_id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `vpsa_id` when calling `remove_vpsa_public_ip`, must conform to the pattern `/vsa-[0-9a-z]+|[0-9]+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'vpsa_id' in params:
            path_params['vpsa_id'] = params['vpsa_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vpsas/{vpsa_id}/public_ip.json', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20037',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def resume_vpsa(self, vpsa_id, **kwargs):  # noqa: E501
        """resume_vpsa  # noqa: E501

        Restore a VPSA from hibernating state.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resume_vpsa(vpsa_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :return: InlineResponse20033
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.resume_vpsa_with_http_info(vpsa_id, **kwargs)  # noqa: E501
        else:
            (data) = self.resume_vpsa_with_http_info(vpsa_id, **kwargs)  # noqa: E501
            return data

    def resume_vpsa_with_http_info(self, vpsa_id, **kwargs):  # noqa: E501
        """resume_vpsa  # noqa: E501

        Restore a VPSA from hibernating state.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resume_vpsa_with_http_info(vpsa_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :return: InlineResponse20033
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['vpsa_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method resume_vpsa" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'vpsa_id' is set
        if self.api_client.client_side_validation and ('vpsa_id' not in params or
                                                       params['vpsa_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vpsa_id` when calling `resume_vpsa`")  # noqa: E501

        if self.api_client.client_side_validation and ('vpsa_id' in params and not re.search(r'vsa-[0-9a-z]+|[0-9]+', params['vpsa_id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `vpsa_id` when calling `resume_vpsa`, must conform to the pattern `/vsa-[0-9a-z]+|[0-9]+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'vpsa_id' in params:
            path_params['vpsa_id'] = params['vpsa_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vpsas/{vpsa_id}/restore.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20033',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_object_account_service_for_vpsa_object_storage(self, vpsa_id, update_object_account, **kwargs):  # noqa: E501
        """update_object_account_service_for_vpsa_object_storage  # noqa: E501

        Update object account service on an existing VPSA Object Storage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_object_account_service_for_vpsa_object_storage(vpsa_id, update_object_account, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :param UpdateObjectAccount update_object_account: (required)
        :return: InlineResponse20044
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_object_account_service_for_vpsa_object_storage_with_http_info(vpsa_id, update_object_account, **kwargs)  # noqa: E501
        else:
            (data) = self.update_object_account_service_for_vpsa_object_storage_with_http_info(vpsa_id, update_object_account, **kwargs)  # noqa: E501
            return data

    def update_object_account_service_for_vpsa_object_storage_with_http_info(self, vpsa_id, update_object_account, **kwargs):  # noqa: E501
        """update_object_account_service_for_vpsa_object_storage  # noqa: E501

        Update object account service on an existing VPSA Object Storage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_object_account_service_for_vpsa_object_storage_with_http_info(vpsa_id, update_object_account, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str vpsa_id: (required)
        :param UpdateObjectAccount update_object_account: (required)
        :return: InlineResponse20044
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['vpsa_id', 'update_object_account']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_object_account_service_for_vpsa_object_storage" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'vpsa_id' is set
        if self.api_client.client_side_validation and ('vpsa_id' not in params or
                                                       params['vpsa_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vpsa_id` when calling `update_object_account_service_for_vpsa_object_storage`")  # noqa: E501
        # verify the required parameter 'update_object_account' is set
        if self.api_client.client_side_validation and ('update_object_account' not in params or
                                                       params['update_object_account'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `update_object_account` when calling `update_object_account_service_for_vpsa_object_storage`")  # noqa: E501

        if self.api_client.client_side_validation and ('vpsa_id' in params and not re.search(r'vsa-[0-9a-z]+|[0-9]+', params['vpsa_id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `vpsa_id` when calling `update_object_account_service_for_vpsa_object_storage`, must conform to the pattern `/vsa-[0-9a-z]+|[0-9]+/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'vpsa_id' in params:
            path_params['vpsa_id'] = params['vpsa_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_object_account' in params:
            body_params = params['update_object_account']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/vpsas/{vpsa_id}/public_zios.json', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20044',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import CommandCenter
from CommandCenter.api.custom_networks_api import CustomNetworksApi  # noqa: E501
from CommandCenter.rest import ApiException


class TestCustomNetworksApi(unittest.TestCase):
    """CustomNetworksApi unit test stubs"""

    def setUp(self):
        self.api = CommandCenter.api.custom_networks_api.CustomNetworksApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_ip_range_to_custom_net(self):
        """Test case for add_ip_range_to_custom_net

        """
        pass

    def test_create_custom_network(self):
        """Test case for create_custom_network

        """
        pass

    def test_delete_custom_network(self):
        """Test case for delete_custom_network

        """
        pass

    def test_get_all_custom_networks(self):
        """Test case for get_all_custom_networks

        """
        pass

    def test_get_custom_network(self):
        """Test case for get_custom_network

        """
        pass

    def test_remove_ip_range_from_custom_net(self):
        """Test case for remove_ip_range_from_custom_net

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse20038NicInformation(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'pci_address': 'str',
        'general_info': 'str',
        'interfaces': 'str',
        'roles': 'str',
        'firmware': 'str',
        'speed': 'str',
        'product_name': 'str',
        'part_number': 'str'
    }

    attribute_map = {
        'pci_address': 'pci_address',
        'general_info': 'general_info',
        'interfaces': 'interfaces',
        'roles': 'roles',
        'firmware': 'firmware',
        'speed': 'speed',
        'product_name': 'product_name',
        'part_number': 'part_number'
    }

    def __init__(self, pci_address=None, general_info=None, interfaces=None, roles=None, firmware=None, speed=None, product_name=None, part_number=None, _configuration=None):  # noqa: E501
        """InlineResponse20038NicInformation - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._pci_address = None
        self._general_info = None
        self._interfaces = None
        self._roles = None
        self._firmware = None
        self._speed = None
        self._product_name = None
        self._part_number = None
        self.discriminator = None

        if pci_address is not None:
            self.pci_address = pci_address
        if general_info is not None:
            self.general_info = general_info
        if interfaces is not None:
            self.interfaces = interfaces
        if roles is not None:
            self.roles = roles
        if firmware is not None:
            self.firmware = firmware
        if speed is not None:
            self.speed = speed
        if product_name is not None:
            self.product_name = product_name
        if part_number is not None:
            self.part_number = part_number

    @property
    def pci_address(self):
        """Gets the pci_address of this InlineResponse20038NicInformation.  # noqa: E501


        :return: The pci_address of this InlineResponse20038NicInformation.  # noqa: E501
        :rtype: str
        """
        return self._pci_address

    @pci_address.setter
    def pci_address(self, pci_address):
        """Sets the pci_address of this InlineResponse20038NicInformation.


        :param pci_address: The pci_address of this InlineResponse20038NicInformation.  # noqa: E501
        :type: str
        """

        self._pci_address = pci_address

    @property
    def general_info(self):
        """Gets the general_info of this InlineResponse20038NicInformation.  # noqa: E501


        :return: The general_info of this InlineResponse20038NicInformation.  # noqa: E501
        :rtype: str
        """
        return self._general_info

    @general_info.setter
    def general_info(self, general_info):
        """Sets the general_info of this InlineResponse20038NicInformation.


        :param general_info: The general_info of this InlineResponse20038NicInformation.  # noqa: E501
        :type: str
        """

        self._general_info = general_info

    @property
    def interfaces(self):
        """Gets the interfaces of this InlineResponse20038NicInformation.  # noqa: E501


        :return: The interfaces of this InlineResponse20038NicInformation.  # noqa: E501
        :rtype: str
        """
        return self._interfaces

    @interfaces.setter
    def interfaces(self, interfaces):
        """Sets the interfaces of this InlineResponse20038NicInformation.


        :param interfaces: The interfaces of this InlineResponse20038NicInformation.  # noqa: E501
        :type: str
        """

        self._interfaces = interfaces

    @property
    def roles(self):
        """Gets the roles of this InlineResponse20038NicInformation.  # noqa: E501


        :return: The roles of this InlineResponse20038NicInformation.  # noqa: E501
        :rtype: str
        """
        return self._roles

    @roles.setter
    def roles(self, roles):
        """Sets the roles of this InlineResponse20038NicInformation.


        :param roles: The roles of this InlineResponse20038NicInformation.  # noqa: E501
        :type: str
        """

        self._roles = roles

    @property
    def firmware(self):
        """Gets the firmware of this InlineResponse20038NicInformation.  # noqa: E501


        :return: The firmware of this InlineResponse20038NicInformation.  # noqa: E501
        :rtype: str
        """
        return self._firmware

    @firmware.setter
    def firmware(self, firmware):
        """Sets the firmware of this InlineResponse20038NicInformation.


        :param firmware: The firmware of this InlineResponse20038NicInformation.  # noqa: E501
        :type: str
        """

        self._firmware = firmware

    @property
    def speed(self):
        """Gets the speed of this InlineResponse20038NicInformation.  # noqa: E501


        :return: The speed of this InlineResponse20038NicInformation.  # noqa: E501
        :rtype: str
        """
        return self._speed

    @speed.setter
    def speed(self, speed):
        """Sets the speed of this InlineResponse20038NicInformation.


        :param speed: The speed of this InlineResponse20038NicInformation.  # noqa: E501
        :type: str
        """

        self._speed = speed

    @property
    def product_name(self):
        """Gets the product_name of this InlineResponse20038NicInformation.  # noqa: E501


        :return: The product_name of this InlineResponse20038NicInformation.  # noqa: E501
        :rtype: str
        """
        return self._product_name

    @product_name.setter
    def product_name(self, product_name):
        """Sets the product_name of this InlineResponse20038NicInformation.


        :param product_name: The product_name of this InlineResponse20038NicInformation.  # noqa: E501
        :type: str
        """

        self._product_name = product_name

    @property
    def part_number(self):
        """Gets the part_number of this InlineResponse20038NicInformation.  # noqa: E501


        :return: The part_number of this InlineResponse20038NicInformation.  # noqa: E501
        :rtype: str
        """
        return self._part_number

    @part_number.setter
    def part_number(self, part_number):
        """Sets the part_number of this InlineResponse20038NicInformation.


        :param part_number: The part_number of this InlineResponse20038NicInformation.  # noqa: E501
        :type: str
        """

        self._part_number = part_number

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20038NicInformation, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20038NicInformation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20038NicInformation):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse200227ResponseVolumes(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'display_name': 'str',
        'cg_display_name': 'str',
        'cg_name': 'str',
        'cg_user_created': 'str',
        'pool_display_name': 'str',
        'pool_name': 'str',
        'status': 'str',
        'virtual_capacity': 'int',
        'server_name': 'str',
        'data_type': 'str',
        'thin': 'str',
        'encryption': 'str',
        'access_type': 'str',
        'read_only': 'str',
        'export_name': 'str',
        'mount_sync': 'str',
        'atime_update': 'str',
        'target': 'str',
        'lun': 'str',
        'cache': 'str',
        'read_iops_limit': 'str',
        'read_mbps_limit': 'str',
        'write_iops_limit': 'str',
        'write_mbps_limit': 'str',
        'created_at': 'str',
        'modified_at': 'str'
    }

    attribute_map = {
        'name': 'name',
        'display_name': 'display_name',
        'cg_display_name': 'cg_display_name',
        'cg_name': 'cg_name',
        'cg_user_created': 'cg_user_created',
        'pool_display_name': 'pool_display_name',
        'pool_name': 'pool_name',
        'status': 'status',
        'virtual_capacity': 'virtual_capacity',
        'server_name': 'server_name',
        'data_type': 'data_type',
        'thin': 'thin',
        'encryption': 'encryption',
        'access_type': 'access_type',
        'read_only': 'read_only',
        'export_name': 'export_name',
        'mount_sync': 'mount_sync',
        'atime_update': 'atime_update',
        'target': 'target',
        'lun': 'lun',
        'cache': 'cache',
        'read_iops_limit': 'read_iops_limit',
        'read_mbps_limit': 'read_mbps_limit',
        'write_iops_limit': 'write_iops_limit',
        'write_mbps_limit': 'write_mbps_limit',
        'created_at': 'created_at',
        'modified_at': 'modified_at'
    }

    def __init__(self, name=None, display_name=None, cg_display_name=None, cg_name=None, cg_user_created=None, pool_display_name=None, pool_name=None, status=None, virtual_capacity=None, server_name=None, data_type=None, thin=None, encryption=None, access_type=None, read_only=None, export_name=None, mount_sync=None, atime_update=None, target=None, lun=None, cache=None, read_iops_limit=None, read_mbps_limit=None, write_iops_limit=None, write_mbps_limit=None, created_at=None, modified_at=None, _configuration=None):  # noqa: E501
        """InlineResponse200227ResponseVolumes - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._display_name = None
        self._cg_display_name = None
        self._cg_name = None
        self._cg_user_created = None
        self._pool_display_name = None
        self._pool_name = None
        self._status = None
        self._virtual_capacity = None
        self._server_name = None
        self._data_type = None
        self._thin = None
        self._encryption = None
        self._access_type = None
        self._read_only = None
        self._export_name = None
        self._mount_sync = None
        self._atime_update = None
        self._target = None
        self._lun = None
        self._cache = None
        self._read_iops_limit = None
        self._read_mbps_limit = None
        self._write_iops_limit = None
        self._write_mbps_limit = None
        self._created_at = None
        self._modified_at = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if display_name is not None:
            self.display_name = display_name
        if cg_display_name is not None:
            self.cg_display_name = cg_display_name
        if cg_name is not None:
            self.cg_name = cg_name
        if cg_user_created is not None:
            self.cg_user_created = cg_user_created
        if pool_display_name is not None:
            self.pool_display_name = pool_display_name
        if pool_name is not None:
            self.pool_name = pool_name
        if status is not None:
            self.status = status
        if virtual_capacity is not None:
            self.virtual_capacity = virtual_capacity
        if server_name is not None:
            self.server_name = server_name
        if data_type is not None:
            self.data_type = data_type
        if thin is not None:
            self.thin = thin
        if encryption is not None:
            self.encryption = encryption
        if access_type is not None:
            self.access_type = access_type
        if read_only is not None:
            self.read_only = read_only
        if export_name is not None:
            self.export_name = export_name
        if mount_sync is not None:
            self.mount_sync = mount_sync
        if atime_update is not None:
            self.atime_update = atime_update
        if target is not None:
            self.target = target
        if lun is not None:
            self.lun = lun
        if cache is not None:
            self.cache = cache
        if read_iops_limit is not None:
            self.read_iops_limit = read_iops_limit
        if read_mbps_limit is not None:
            self.read_mbps_limit = read_mbps_limit
        if write_iops_limit is not None:
            self.write_iops_limit = write_iops_limit
        if write_mbps_limit is not None:
            self.write_mbps_limit = write_mbps_limit
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at

    @property
    def name(self):
        """Gets the name of this InlineResponse200227ResponseVolumes.  # noqa: E501


        :return: The name of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse200227ResponseVolumes.


        :param name: The name of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def display_name(self):
        """Gets the display_name of this InlineResponse200227ResponseVolumes.  # noqa: E501


        :return: The display_name of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this InlineResponse200227ResponseVolumes.


        :param display_name: The display_name of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def cg_display_name(self):
        """Gets the cg_display_name of this InlineResponse200227ResponseVolumes.  # noqa: E501


        :return: The cg_display_name of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._cg_display_name

    @cg_display_name.setter
    def cg_display_name(self, cg_display_name):
        """Sets the cg_display_name of this InlineResponse200227ResponseVolumes.


        :param cg_display_name: The cg_display_name of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._cg_display_name = cg_display_name

    @property
    def cg_name(self):
        """Gets the cg_name of this InlineResponse200227ResponseVolumes.  # noqa: E501


        :return: The cg_name of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._cg_name

    @cg_name.setter
    def cg_name(self, cg_name):
        """Sets the cg_name of this InlineResponse200227ResponseVolumes.


        :param cg_name: The cg_name of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._cg_name = cg_name

    @property
    def cg_user_created(self):
        """Gets the cg_user_created of this InlineResponse200227ResponseVolumes.  # noqa: E501


        :return: The cg_user_created of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._cg_user_created

    @cg_user_created.setter
    def cg_user_created(self, cg_user_created):
        """Sets the cg_user_created of this InlineResponse200227ResponseVolumes.


        :param cg_user_created: The cg_user_created of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._cg_user_created = cg_user_created

    @property
    def pool_display_name(self):
        """Gets the pool_display_name of this InlineResponse200227ResponseVolumes.  # noqa: E501


        :return: The pool_display_name of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._pool_display_name

    @pool_display_name.setter
    def pool_display_name(self, pool_display_name):
        """Sets the pool_display_name of this InlineResponse200227ResponseVolumes.


        :param pool_display_name: The pool_display_name of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._pool_display_name = pool_display_name

    @property
    def pool_name(self):
        """Gets the pool_name of this InlineResponse200227ResponseVolumes.  # noqa: E501


        :return: The pool_name of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._pool_name

    @pool_name.setter
    def pool_name(self, pool_name):
        """Sets the pool_name of this InlineResponse200227ResponseVolumes.


        :param pool_name: The pool_name of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._pool_name = pool_name

    @property
    def status(self):
        """Gets the status of this InlineResponse200227ResponseVolumes.  # noqa: E501


        :return: The status of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InlineResponse200227ResponseVolumes.


        :param status: The status of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def virtual_capacity(self):
        """Gets the virtual_capacity of this InlineResponse200227ResponseVolumes.  # noqa: E501


        :return: The virtual_capacity of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :rtype: int
        """
        return self._virtual_capacity

    @virtual_capacity.setter
    def virtual_capacity(self, virtual_capacity):
        """Sets the virtual_capacity of this InlineResponse200227ResponseVolumes.


        :param virtual_capacity: The virtual_capacity of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :type: int
        """

        self._virtual_capacity = virtual_capacity

    @property
    def server_name(self):
        """Gets the server_name of this InlineResponse200227ResponseVolumes.  # noqa: E501


        :return: The server_name of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._server_name

    @server_name.setter
    def server_name(self, server_name):
        """Sets the server_name of this InlineResponse200227ResponseVolumes.


        :param server_name: The server_name of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._server_name = server_name

    @property
    def data_type(self):
        """Gets the data_type of this InlineResponse200227ResponseVolumes.  # noqa: E501


        :return: The data_type of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this InlineResponse200227ResponseVolumes.


        :param data_type: The data_type of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._data_type = data_type

    @property
    def thin(self):
        """Gets the thin of this InlineResponse200227ResponseVolumes.  # noqa: E501


        :return: The thin of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._thin

    @thin.setter
    def thin(self, thin):
        """Sets the thin of this InlineResponse200227ResponseVolumes.


        :param thin: The thin of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._thin = thin

    @property
    def encryption(self):
        """Gets the encryption of this InlineResponse200227ResponseVolumes.  # noqa: E501


        :return: The encryption of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._encryption

    @encryption.setter
    def encryption(self, encryption):
        """Sets the encryption of this InlineResponse200227ResponseVolumes.


        :param encryption: The encryption of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._encryption = encryption

    @property
    def access_type(self):
        """Gets the access_type of this InlineResponse200227ResponseVolumes.  # noqa: E501


        :return: The access_type of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._access_type

    @access_type.setter
    def access_type(self, access_type):
        """Sets the access_type of this InlineResponse200227ResponseVolumes.


        :param access_type: The access_type of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._access_type = access_type

    @property
    def read_only(self):
        """Gets the read_only of this InlineResponse200227ResponseVolumes.  # noqa: E501


        :return: The read_only of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._read_only

    @read_only.setter
    def read_only(self, read_only):
        """Sets the read_only of this InlineResponse200227ResponseVolumes.


        :param read_only: The read_only of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._read_only = read_only

    @property
    def export_name(self):
        """Gets the export_name of this InlineResponse200227ResponseVolumes.  # noqa: E501


        :return: The export_name of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._export_name

    @export_name.setter
    def export_name(self, export_name):
        """Sets the export_name of this InlineResponse200227ResponseVolumes.


        :param export_name: The export_name of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._export_name = export_name

    @property
    def mount_sync(self):
        """Gets the mount_sync of this InlineResponse200227ResponseVolumes.  # noqa: E501


        :return: The mount_sync of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._mount_sync

    @mount_sync.setter
    def mount_sync(self, mount_sync):
        """Sets the mount_sync of this InlineResponse200227ResponseVolumes.


        :param mount_sync: The mount_sync of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._mount_sync = mount_sync

    @property
    def atime_update(self):
        """Gets the atime_update of this InlineResponse200227ResponseVolumes.  # noqa: E501


        :return: The atime_update of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._atime_update

    @atime_update.setter
    def atime_update(self, atime_update):
        """Sets the atime_update of this InlineResponse200227ResponseVolumes.


        :param atime_update: The atime_update of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._atime_update = atime_update

    @property
    def target(self):
        """Gets the target of this InlineResponse200227ResponseVolumes.  # noqa: E501


        :return: The target of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """Sets the target of this InlineResponse200227ResponseVolumes.


        :param target: The target of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._target = target

    @property
    def lun(self):
        """Gets the lun of this InlineResponse200227ResponseVolumes.  # noqa: E501


        :return: The lun of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._lun

    @lun.setter
    def lun(self, lun):
        """Sets the lun of this InlineResponse200227ResponseVolumes.


        :param lun: The lun of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._lun = lun

    @property
    def cache(self):
        """Gets the cache of this InlineResponse200227ResponseVolumes.  # noqa: E501


        :return: The cache of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._cache

    @cache.setter
    def cache(self, cache):
        """Sets the cache of this InlineResponse200227ResponseVolumes.


        :param cache: The cache of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._cache = cache

    @property
    def read_iops_limit(self):
        """Gets the read_iops_limit of this InlineResponse200227ResponseVolumes.  # noqa: E501


        :return: The read_iops_limit of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._read_iops_limit

    @read_iops_limit.setter
    def read_iops_limit(self, read_iops_limit):
        """Sets the read_iops_limit of this InlineResponse200227ResponseVolumes.


        :param read_iops_limit: The read_iops_limit of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._read_iops_limit = read_iops_limit

    @property
    def read_mbps_limit(self):
        """Gets the read_mbps_limit of this InlineResponse200227ResponseVolumes.  # noqa: E501


        :return: The read_mbps_limit of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._read_mbps_limit

    @read_mbps_limit.setter
    def read_mbps_limit(self, read_mbps_limit):
        """Sets the read_mbps_limit of this InlineResponse200227ResponseVolumes.


        :param read_mbps_limit: The read_mbps_limit of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._read_mbps_limit = read_mbps_limit

    @property
    def write_iops_limit(self):
        """Gets the write_iops_limit of this InlineResponse200227ResponseVolumes.  # noqa: E501


        :return: The write_iops_limit of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._write_iops_limit

    @write_iops_limit.setter
    def write_iops_limit(self, write_iops_limit):
        """Sets the write_iops_limit of this InlineResponse200227ResponseVolumes.


        :param write_iops_limit: The write_iops_limit of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._write_iops_limit = write_iops_limit

    @property
    def write_mbps_limit(self):
        """Gets the write_mbps_limit of this InlineResponse200227ResponseVolumes.  # noqa: E501


        :return: The write_mbps_limit of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._write_mbps_limit

    @write_mbps_limit.setter
    def write_mbps_limit(self, write_mbps_limit):
        """Sets the write_mbps_limit of this InlineResponse200227ResponseVolumes.


        :param write_mbps_limit: The write_mbps_limit of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._write_mbps_limit = write_mbps_limit

    @property
    def created_at(self):
        """Gets the created_at of this InlineResponse200227ResponseVolumes.  # noqa: E501


        :return: The created_at of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InlineResponse200227ResponseVolumes.


        :param created_at: The created_at of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this InlineResponse200227ResponseVolumes.  # noqa: E501


        :return: The modified_at of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this InlineResponse200227ResponseVolumes.


        :param modified_at: The modified_at of this InlineResponse200227ResponseVolumes.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse200227ResponseVolumes, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse200227ResponseVolumes):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse200227ResponseVolumes):
            return True

        return self.to_dict() != other.to_dict()
